@@ -1,6 +1,6 @@
 use utf8;
 package Mojolicious::Plugin::DevexpressHelpers::Helpers;
-$Mojolicious::Plugin::DevexpressHelpers::Helpers::VERSION = '0.151480';
+$Mojolicious::Plugin::DevexpressHelpers::Helpers::VERSION = '0.151530';
 #ABSTRACT: Helpers for Devexpress controls are defined here
 use Modern::Perl;
 use Mojo::ByteStream;
@@ -186,6 +186,29 @@ sub dxtextbox{
 }
 
 
+sub dxlookup{
+	my $c = shift;
+	my $attrs = parse_attributs( $c, [qw(id value label)], @_ );
+	my $id = delete($attrs->{id});
+	if (my $name = $id) {
+		$attrs->{attr}{name}=$name;
+	}
+	
+	$id //= new_id( $c, $attrs );
+
+	my (@before, @after);
+	if(my $label = delete($attrs->{label})){
+		push @before, '<div class="dx-field">';
+		push @before, '<div class="dx-field-label">'.$label.'</div>';
+		push @before, '<div class="dx-field-value">';
+		push @after, '</div>';
+		push @after, '</div>';
+	}
+	
+	dxbind( $c, 'dxLookup' => $id => $attrs, undef, \@before, \@after );	
+}
+
+
 
 sub dxbuild {
 	my $c = shift;
@@ -225,7 +248,7 @@ my @without_prefix = qw( dxbuild required_assets require_asset );
 
 #Helper method to export with prepending a prefix
 my @with_prefix = qw( Button DataGrid Popup TextBox TextArea Switch
-	SelectBox NumberBox List DateBox CheckBox Calendar Box);
+	SelectBox NumberBox List DateBox CheckBox Calendar Box Lookup );
 sub register {
 	my ( $self, $app, $args ) = @_;
 	my $tp = $args->{tag_prefix};
@@ -271,7 +294,7 @@ Mojolicious::Plugin::DevexpressHelpers::Helpers - Helpers for Devexpress control
 
 =head1 VERSION
 
-version 0.151480
+version 0.151530
 
 =head1 SUBROUTINES/METHODS
 
@@ -362,8 +385,11 @@ B<Note: It will ignore all other options specified in the hash reference.>
 
 	%= dxtextbox 'name' => $value => 'Name: ', { placeHolder => 'Type a name' }
 
+=head2 dxlookup C<[ $id, [ $value, [ $label, ] ] ], [\%opts]>
+
+	%= dxlookup 'name' => $value => 'Name: ', { dataSource => $ds, valueExpr=> $ve, displayExpr => $de }
+
 =for comment TextArea
-Switch
 SelectBox
 NumberBox
 List
